gs_quant.timeseries.econometrics.change — gs_quant 0.1 documentation

# gs_quant.timeseries.econometrics.change

`change`(x)

  Arithmetic series normalization

  Parameters

    x (`Series`) – time series

  Return type

    `Series`

  Returns

    normalized time series

  Usage

  Compute difference of every value from the initial value of x:

  \(Y_t = X_t - X_0\)

  where \(X_0\) is the first value in the series

  Examples

  Change in level from initial value:

      >>> series = generate_series(100)
      >>> returns = change(series)

  See also

  `index()`